@@ -579,7 +579,15 @@ static SC_HTMLTag *sc_html_get_tag(const gchar *str)
 				tmpp++;
 				attr_value = tmpp;
 				if ((p = strchr(attr_value, quote)) == NULL) {
-					g_warning("sc_html_get_tag(): syntax error in tag: '%s'", str);
+					if (debug_get_mode()) {
+						g_warning("sc_html_get_tag(): syntax error in tag: '%s'",
+								  str);
+					} else {
+						gchar *cut = g_strndup(str, 100);
+						g_warning("sc_html_get_tag(): syntax error in tag: '%s%s'",
+								  cut, strlen(str)>100?"...":".");
+						g_free(cut);
+					}
 					return tag;
 				}
 				tmpp = p;
