@@ -32,7 +32,7 @@
 #ifdef USE_PTHREAD
 #include <pthread.h>
 #endif
-#include <ical.h>
+#include <libical/ical.h>
 #include "vcalendar.h"
 #include "vcal_folder.h"
 #include "vcal_manager.h"
@@ -50,6 +50,7 @@
 #include "folder.h"
 #include "quoted-printable.h"
 #include "utils.h"
+#include "defs.h"
 
 #ifdef G_OS_WIN32
 #define getuid() 0
@@ -57,8 +58,8 @@
 
 Answer *answer_new(const gchar *attendee, 
 			  const gchar *name,
-			  enum icalparameter_partstat ans,
-			  enum icalparameter_cutype cutype)
+			  icalparameter_partstat ans,
+			  icalparameter_cutype cutype)
 {
 	Answer *answer = g_new0(Answer, 1);
 	answer->attendee = g_strdup(attendee);
@@ -103,7 +104,7 @@ void vcal_manager_copy_attendees(VCalEvent *src, VCalEvent *dest)
 	dest->answers = g_slist_reverse(dest->answers);
 }
 
-gchar *vcal_manager_answer_get_text(enum icalparameter_partstat ans) 
+gchar *vcal_manager_answer_get_text(icalparameter_partstat ans) 
 {
 	static gchar *replies[5]={
 		N_("accepted"),
@@ -130,13 +131,14 @@ gchar *vcal_manager_answer_get_text(enum icalparameter_partstat ans)
 	case ICAL_PARTSTAT_X:
 	case ICAL_PARTSTAT_INPROCESS:
 	case ICAL_PARTSTAT_NONE:
+  case ICAL_PARTSTAT_FAILED:
 		return _(replies[4]);
 		break;			
 	}
 	return NULL;
 }
 
-gchar *vcal_manager_cutype_get_text(enum icalparameter_cutype type) 
+gchar *vcal_manager_cutype_get_text(icalparameter_cutype type) 
 {
 	static gchar *replies[5]={
 		N_("individual"),
@@ -195,11 +197,11 @@ GSList *vcal_manager_get_answers_emails(VCalEvent *event)
 	return new;	
 }
 
-enum icalparameter_partstat vcal_manager_get_reply_for_attendee(VCalEvent *event, const gchar *att)
+icalparameter_partstat vcal_manager_get_reply_for_attendee(VCalEvent *event, const gchar *att)
 {
 	Answer *a = answer_new(att, NULL, 0, 0);
 	GSList *ans = answer_find(event, a);
-	enum icalparameter_partstat res = 0;
+	icalparameter_partstat res = 0;
 	if (ans) {
 		Answer *b = (Answer *)ans->data;
 		res = b->answer;
@@ -210,7 +212,7 @@ enum icalparameter_partstat vcal_manager_get_reply_for_attendee(VCalEvent *event
 
 gchar *vcal_manager_get_cutype_text_for_attendee(VCalEvent *event, const gchar *att)
 {
-	enum icalparameter_cutype status = vcal_manager_get_cutype_for_attendee(event, att);
+	icalparameter_cutype status = vcal_manager_get_cutype_for_attendee(event, att);
 	gchar *res = NULL;
 	if (status != 0) 
 		res = g_strdup(vcal_manager_cutype_get_text(status));
@@ -218,11 +220,11 @@ gchar *vcal_manager_get_cutype_text_for_attendee(VCalEvent *event, const gchar *
 	return res;
 }
 
-enum icalparameter_partstat vcal_manager_get_cutype_for_attendee(VCalEvent *event, const gchar *att)
+icalparameter_partstat vcal_manager_get_cutype_for_attendee(VCalEvent *event, const gchar *att)
 {
 	Answer *a = answer_new(att, NULL, 0, 0);
 	GSList *ans = answer_find(event, a);
-	enum icalparameter_cutype res = 0;
+	icalparameter_cutype res = 0;
 	if (ans) {
 		Answer *b = (Answer *)ans->data;
 		res = b->cutype;
@@ -233,7 +235,7 @@ enum icalparameter_partstat vcal_manager_get_cutype_for_attendee(VCalEvent *even
 
 gchar *vcal_manager_get_reply_text_for_attendee(VCalEvent *event, const gchar *att)
 {
-	enum icalparameter_partstat status = vcal_manager_get_reply_for_attendee(event, att);
+	icalparameter_partstat status = vcal_manager_get_reply_for_attendee(event, att);
 	gchar *res = NULL;
 	if (status != 0) 
 		res = g_strdup(vcal_manager_answer_get_text(status));
@@ -311,7 +313,7 @@ gchar *vcal_manager_event_dump(VCalEvent *event, gboolean is_reply, gboolean is_
 	icalcomponent *calendar, *ievent, *timezone, *tzc;
 	icalproperty *attprop;
 	icalproperty *orgprop;
-	enum icalparameter_partstat status = ICAL_PARTSTAT_NEEDSACTION;
+	icalparameter_partstat status = ICAL_PARTSTAT_NEEDSACTION;
 	gchar *sanitized_uid = g_strdup(event->uid);
 	
 	subst_for_filename(sanitized_uid);
@@ -409,9 +411,9 @@ gchar *vcal_manager_event_dump(VCalEvent *event, gboolean is_reply, gboolean is_
 	icalcomponent_add_property(ievent,
 		icalproperty_new_sequence(modif && !is_reply ? event->sequence + 1 : event->sequence));
 	icalcomponent_add_property(ievent,
-		icalproperty_new_class("PUBLIC"));
+		icalproperty_new_class(ICAL_CLASS_PUBLIC));
 	icalcomponent_add_property(ievent,
-		icalproperty_new_transp("OPAQUE"));
+		icalproperty_new_transp(ICAL_TRANSP_OPAQUE));
 	if (event->location && *event->location)
 		icalcomponent_add_property(ievent,
 			icalproperty_new_location(event->location));
@@ -544,7 +546,7 @@ static gchar *write_headers_date(const gchar *uid)
 {
 	gchar subject[512];
 	gchar *t_subject;
-	gchar date[128];
+	gchar date[RFC822_DATE_BUFFSIZE];
 	time_t t;
 	struct tm lt;
 
@@ -776,9 +778,9 @@ VCalEvent * vcal_manager_new_event	(const gchar 	*uid,
 					 const gchar	*recur,
 					 const gchar	*tzid,
 					 const gchar	*url,
-					 enum icalproperty_method method,
+					 icalproperty_method method,
 					 gint 		 sequence,
-					 enum icalcomponent_kind type)
+					 icalcomponent_kind type)
 {
 	VCalEvent *event = g_new0(VCalEvent, 1);
 
@@ -788,28 +790,16 @@ VCalEvent * vcal_manager_new_event	(const gchar 	*uid,
 
 	if (dtend && *(dtend)) {
 		time_t tmp = icaltime_as_timet((icaltime_from_string(dtend)));
-#ifdef G_OS_WIN32
 		GDateTime *dt = g_date_time_new_from_unix_local(tmp);
-		event->end = g_date_time_format(dt, "%a, %e %b %Y %H:%M:%S %z");
+		event->end = g_date_time_format(dt, "%a, %e %b %Y %H:%M:%S %Z");
 		g_date_time_unref(dt);
-#else
-		gchar buft[512];
-		tzset();
-		event->end	= g_strdup(ctime_r(&tmp, buft));
-#endif
 	}
 	
 	if (dtstart && *(dtstart)) {
 		time_t tmp = icaltime_as_timet((icaltime_from_string(dtstart)));
-#ifdef G_OS_WIN32
 		GDateTime *dt = g_date_time_new_from_unix_local(tmp);
-		event->start = g_date_time_format(dt, "%a, %e %b %Y %H:%M:%S %z");
+		event->start = g_date_time_format(dt, "%a, %e %b %Y %H:%M:%S %Z");
 		g_date_time_unref(dt);
-#else
-		gchar buft[512];
-		tzset();
-		event->start	= g_strdup(ctime_r(&tmp, buft));
-#endif
 	}
 	event->dtstart		= g_strdup(dtstart?dtstart:"");
 	event->dtend		= g_strdup(dtend?dtend:"");
@@ -1002,8 +992,8 @@ static VCalEvent *event_get_from_xml (const gchar *uid, GNode *node)
 	gchar *dtstart = NULL, *dtend = NULL, *tzid = NULL;
 	gchar *description = NULL, *url = NULL, *recur = NULL;
 	VCalEvent *event = NULL;
-	enum icalproperty_method method = ICAL_METHOD_REQUEST;
-	enum icalcomponent_kind type = ICAL_VEVENT_COMPONENT;
+	icalproperty_method method = ICAL_METHOD_REQUEST;
+	icalcomponent_kind type = ICAL_VEVENT_COMPONENT;
 	gint sequence = 0, rec_occurrence = 0;
 	time_t postponed = (time_t)0;
 	
@@ -1074,8 +1064,8 @@ static VCalEvent *event_get_from_xml (const gchar *uid, GNode *node)
 	while (node != NULL) {
 		gchar *attendee = NULL;
 		gchar *name = NULL;
-		enum icalparameter_partstat answer = ICAL_PARTSTAT_NEEDSACTION;
-		enum icalparameter_cutype cutype   = ICAL_CUTYPE_INDIVIDUAL;
+		icalparameter_partstat answer = ICAL_PARTSTAT_NEEDSACTION;
+		icalparameter_cutype cutype   = ICAL_CUTYPE_INDIVIDUAL;
 		
 		xmlnode = node->data;
 		if (strcmp2(xmlnode->tag->tag, "answer") != 0) {
@@ -1146,8 +1136,8 @@ VCalEvent *vcal_manager_load_event (const gchar *uid)
 void vcal_manager_update_answer (VCalEvent 	*event, 
 				 const gchar 	*attendee,
 				 const gchar	*name,
-				 enum icalparameter_partstat ans,
-				 enum icalparameter_cutype cutype)
+				 icalparameter_partstat ans,
+				 icalparameter_cutype cutype)
 {
 	Answer *answer = NULL;
 	GSList *existing = NULL;
@@ -1182,13 +1172,13 @@ static gchar *write_headers(PrefsAccount 	*account,
 			    gboolean 		 is_pseudo_display)
 {
 	gchar *subject = NULL;
-	gchar date[128];
+	gchar date[RFC822_DATE_BUFFSIZE];
 	gchar *save_folder = NULL;
 	gchar *result = NULL;
 	gchar *queue_headers = NULL;
 	gchar *method_str = NULL;
 	gchar *attendees = NULL;
-	enum icalparameter_partstat status;
+	icalparameter_partstat status;
 	gchar *prefix = NULL;
 	gchar enc_subject[512], enc_from[512], *from = NULL;
 	gchar *msgid;
@@ -1323,7 +1313,7 @@ static gchar *write_headers_ical(PrefsAccount 	*account,
 			    gchar 		*orga)
 {
 	gchar subject[512];
-	gchar date[128];
+	gchar date[RFC822_DATE_BUFFSIZE];
 	gchar *result = NULL;
 	gchar *method_str = NULL;
 	gchar *summary = NULL;
