@@ -32,7 +32,7 @@
 #ifdef USE_PTHREAD
 #include <pthread.h>
 #endif
-#include <ical.h>
+#include <libical/ical.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <curl/curl.h>
@@ -1225,7 +1225,7 @@ static gboolean send_meeting_cb(GtkButton *widget, gpointer data)
 	PrefsAccount *account = NULL;
 	gboolean res = FALSE;
 	gboolean found_att = FALSE;
-	Folder *folder = folder_find_from_name ("vCalendar", vcal_folder_get_class());
+	Folder *folder = folder_find_from_name (PLUGIN_NAME, vcal_folder_get_class());
 	gboolean redisp = FALSE;
 
 	if (meet->uid == NULL && meet->visible && 
@@ -1981,13 +1981,13 @@ void multisync_export(void)
 		for (cur = files; cur; cur = cur->next) {
 			file = (char *)cur->data;
 			if (fprintf(fp, "1 1 %s\n", file) < 0)
-				perror(file);
+				FILE_OP_ERROR(file, "fprintf");
 			g_free(file);
 		}
 		if (fclose(fp) == EOF)
-			perror(file);
+			FILE_OP_ERROR(file, "fclose");
 	} else {
-		perror(file);
+		FILE_OP_ERROR(file, "fopen");
 	}
 	g_free(path);
 	g_slist_free(files);
