@@ -27,7 +27,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 
-#include <ical.h>
+#include <libical/ical.h>
 #include <gtk/gtk.h>
 
 #if USE_PTHREAD
@@ -317,7 +317,7 @@ static VCalEvent *vcalviewer_get_component(const gchar *file, const gchar *chars
 	g_free(tmplbl);						\
 }
 
-static void vcalviewer_answer_set_choices(VCalViewer *vcalviewer, VCalEvent *event, enum icalproperty_method method);
+static void vcalviewer_answer_set_choices(VCalViewer *vcalviewer, VCalEvent *event, icalproperty_method method);
 
 static void vcalviewer_reset(VCalViewer *vcalviewer) 
 {
@@ -353,7 +353,7 @@ static void vcalviewer_show_unavailable(VCalViewer *vcalviewer, gboolean visi)
 		gtk_widget_hide(vcalviewer->unavail_box);
 }
 
-static void vcalviewer_answer_set_choices(VCalViewer *vcalviewer, VCalEvent *event, enum icalproperty_method method)
+static void vcalviewer_answer_set_choices(VCalViewer *vcalviewer, VCalEvent *event, icalproperty_method method)
 {
 	int i = 0;
 	
@@ -408,7 +408,7 @@ static void vcalviewer_answer_set_choices(VCalViewer *vcalviewer, VCalEvent *eve
 		gchar *myfb = file_read_to_str(internal_ifb);
 		g_free(internal_ifb);
 		if (account) {
-			enum icalparameter_partstat answer = 
+			icalparameter_partstat answer = 
 				vcal_manager_get_reply_for_attendee(event, account->address);
 				
 			if (answer == ICAL_PARTSTAT_ACCEPTED)
@@ -441,7 +441,7 @@ static FolderItem *vcalendar_get_current_item(void)
 {
 	MainWindow *mainwin = mainwindow_get_mainwindow();
 	FolderItem *item = NULL;
-	Folder *folder = folder_find_from_name ("vCalendar", vcal_folder_get_class());
+	Folder *folder = folder_find_from_name (PLUGIN_NAME, vcal_folder_get_class());
 	
 	if (mainwin) {
 		item = mainwin->summaryview->folder_item;
@@ -588,7 +588,7 @@ void vcalviewer_display_event (VCalViewer *vcalviewer, VCalEvent *event)
 		gchar *name = vcal_manager_get_attendee_name(event, attendee);
 		gchar *ename = g_markup_printf_escaped("%s", name?name:"");
 		gchar *eatt = g_markup_printf_escaped("%s", attendee);
-		enum icalparameter_partstat acode = vcal_manager_get_reply_for_attendee(event, attendee);
+		icalparameter_partstat acode = vcal_manager_get_reply_for_attendee(event, attendee);
 		gchar *answer = vcal_manager_get_reply_text_for_attendee(event, attendee);
 		gchar *type = vcal_manager_get_cutype_text_for_attendee(event, attendee);
 		gchar *tmp = NULL;
@@ -897,7 +897,7 @@ void vcalviewer_reload(FolderItem *item)
 {
 	if (s_vcalviewer) {
 		MainWindow *mainwin = mainwindow_get_mainwindow();
-		Folder *folder = folder_find_from_name ("vCalendar", vcal_folder_get_class());
+		Folder *folder = folder_find_from_name (PLUGIN_NAME, vcal_folder_get_class());
 
 		folder_item_scan(item);
 		if (mainwin && mainwin->summaryview->folder_item) {
@@ -950,7 +950,7 @@ static gboolean vcalviewer_uribtn_cb(GtkButton *widget, gpointer data)
 
 void vcalendar_refresh_folder_contents(FolderItem *item)
 {
-	Folder *folder = folder_find_from_name ("vCalendar", vcal_folder_get_class());
+	Folder *folder = folder_find_from_name (PLUGIN_NAME, vcal_folder_get_class());
 	if (folder && item->folder == folder) {
 		MainWindow *mainwin = mainwindow_get_mainwindow();
 		folder_item_scan(item);
@@ -971,7 +971,7 @@ void vcalendar_cancel_meeting(FolderItem *item, const gchar *uid)
 	VCalMeeting *meet = NULL;
 	gchar *file = NULL;
 	gint val = 0;
-	Folder *folder = folder_find_from_name ("vCalendar", vcal_folder_get_class());
+	Folder *folder = folder_find_from_name (PLUGIN_NAME, vcal_folder_get_class());
 	gboolean redisp = FALSE;
 	GtkWidget *send_notify_chkbtn = gtk_check_button_new_with_label(_("Send a notification to the attendees"));
 	gboolean send_notify = TRUE;
@@ -1049,7 +1049,7 @@ static gboolean vcalviewer_action_cb(GtkButton *widget, gpointer data)
 {
         VCalViewer *vcalviewer = (VCalViewer *)data;
 	gint index = gtk_combo_box_get_active(GTK_COMBO_BOX(vcalviewer->answer));
-	enum icalparameter_partstat reply[3] = {ICAL_PARTSTAT_ACCEPTED, ICAL_PARTSTAT_TENTATIVE, ICAL_PARTSTAT_DECLINED};
+	icalparameter_partstat reply[3] = {ICAL_PARTSTAT_ACCEPTED, ICAL_PARTSTAT_TENTATIVE, ICAL_PARTSTAT_DECLINED};
 	PrefsAccount *account = NULL;
 	VCalEvent *saved_event = NULL, *event = NULL;
 	debug_print("index chosen %d\n", index);
@@ -1294,7 +1294,7 @@ static gint scan_timeout_tag = 0;
 
 static gboolean vcal_webcal_check(gpointer data)
 {
-	Folder *root = folder_find_from_name ("vCalendar", vcal_folder_get_class());
+	Folder *root = folder_find_from_name (PLUGIN_NAME, vcal_folder_get_class());
 
 	if (prefs_common_get_prefs()->work_offline)
 		return TRUE;
@@ -1327,10 +1327,10 @@ void vcalendar_init(void)
 	mimeview_register_viewer_factory(&vcal_viewer_factory);
 	folder_register_class(vcal_folder_get_class());
 
-	folder = folder_find_from_name ("vCalendar", vcal_folder_get_class());
+	folder = folder_find_from_name (PLUGIN_NAME, vcal_folder_get_class());
 	if (!folder) {
 		START_TIMING("creating folder");
-		folder = folder_new(vcal_folder_get_class(), "vCalendar", NULL);
+		folder = folder_new(vcal_folder_get_class(), PLUGIN_NAME, NULL);
 		folder->klass->create_tree(folder);
 		folder_add(folder);
 		folder_scan_tree(folder, TRUE);
