@@ -121,6 +121,16 @@ static PrefParam param_os_specific[] = {
 	/* Interface */
 	{"pixmap_theme_path", DEFAULT_PIXMAP_THEME, 
 	 &prefs_common.pixmap_theme_path, P_STRING, NULL, NULL, NULL},
+#ifdef HAVE_SVG
+	{"enable_alpha_svg", "TRUE",
+	 &prefs_common.enable_alpha_svg, P_BOOL, NULL, NULL, NULL},
+	{"enable_pixmap_scaling", "TRUE",
+	 &prefs_common.enable_pixmap_scaling, P_BOOL, NULL, NULL, NULL},
+	{"pixmap_scaling_auto", "TRUE",
+	 &prefs_common.pixmap_scaling_auto, P_BOOL, NULL, NULL, NULL},
+	{"pixmap_scaling_ppi", "96",
+	 &prefs_common.pixmap_scaling_ppi, P_INT, NULL, NULL, NULL},
+#endif
 
 	/* Other */
 	{"ext_editor_command", "notepad %s",
@@ -203,6 +213,8 @@ static PrefParam param[] = {
 	  P_BOOL, NULL, NULL, NULL},
 	{"warn_empty_subj", "TRUE", &prefs_common.warn_empty_subj,
 	 P_BOOL, NULL, NULL, NULL},
+	{"warn_sending_many_recipients_num", "0", &prefs_common.warn_sending_many_recipients_num, P_INT,
+	 NULL, NULL, NULL},
 	{"hide_timezone", "FALSE", &prefs_common.hide_timezone,
 	 P_BOOL, NULL, NULL, NULL},
 	{"allow_jisx0201_kana", "FALSE", &prefs_common.allow_jisx0201_kana,
@@ -315,19 +327,7 @@ static PrefParam param[] = {
 	 NULL, NULL, NULL},
 
 	/* Display */
-	/* Obsolete fonts. For coexisting with Gtk+-1.2 version */
-	{"widget_font",		NULL,
-	  &prefs_common.widgetfont_gtk1,	P_STRING, NULL, NULL, NULL},
-	{"message_font",	"-misc-fixed-medium-r-normal--14-*-*-*-*-*-*-*",
-	 &prefs_common.textfont_gtk1,		P_STRING, NULL, NULL, NULL},
-	{"small_font",		"-*-helvetica-medium-r-normal--10-*-*-*-*-*-*-*",
-	  &prefs_common.smallfont_gtk1,		P_STRING, NULL, NULL, NULL},
-	{"bold_font",		"-*-helvetica-bold-r-normal--12-*-*-*-*-*-*-*",
-	  &prefs_common.boldfont_gtk1,		P_STRING, NULL, NULL, NULL},
-	{"normal_font",		"-*-helvetica-medium-r-normal--12-*-*-*-*-*-*-*",
-	  &prefs_common.normalfont_gtk1,	P_STRING, NULL, NULL, NULL},
-
-	/* new fonts */
+	/* fonts */
 #ifndef GENERIC_UMPC
 	{"widget_font_gtk2",	NULL,
 	  &SPECIFIC_PREFS.widgetfont,		P_STRING, NULL, NULL, NULL},
@@ -726,6 +726,23 @@ static PrefParam param[] = {
 	{"recycle_quote_colors", "FALSE", &prefs_common.recycle_quote_colors,
 	 P_BOOL, NULL, NULL, NULL},
 
+	{"default_header_color", "#000000", &prefs_common.default_header_color, P_COLOR,
+	 NULL, NULL, NULL},
+	{"default_header_bgcolor", "#f5f6be", &prefs_common.default_header_bgcolor, P_COLOR,
+	 NULL, NULL, NULL},
+	{"tags_color", "#000000", &prefs_common.tags_color, P_COLOR,
+	 NULL, NULL, NULL},
+	{"tags_bgcolor", "#f5f6be", &prefs_common.tags_bgcolor, P_COLOR,
+	 NULL, NULL, NULL},
+	{"qs_active_color", "#000000", &prefs_common.qs_active_color, P_COLOR,
+	 NULL, NULL, NULL},
+	{"qs_active_bgcolor", "#f5f6be", &prefs_common.qs_active_bgcolor, P_COLOR,
+	 NULL, NULL, NULL},
+	{"qs_error_color", "#000000", &prefs_common.qs_error_color, P_COLOR,
+	 NULL, NULL, NULL},
+	{"qs_error_bgcolor", "#ff7070", &prefs_common.qs_error_bgcolor, P_COLOR,
+	 NULL, NULL, NULL},
+
 	{"display_header_pane", "FALSE", &prefs_common.display_header_pane,
 	 P_BOOL, NULL, NULL, NULL},
 	{"display_header", "TRUE", &prefs_common.display_header, P_BOOL,
@@ -771,7 +788,7 @@ static PrefParam param[] = {
 	/* MIME viewer */
 	{"mime_textviewer",   NULL,
 	 &SPECIFIC_PREFS.mime_textviewer,   P_STRING, NULL, NULL, NULL},
-	{"mime_open_command", "gedit '%s'",
+	{"mime_open_command", "xdg-open '%s'",
 	 &SPECIFIC_PREFS.mime_open_cmd,     P_STRING, NULL, NULL, NULL},
 	{"show_inline_attachments", "TRUE", 
 	 &prefs_common.show_inline_attachments, P_BOOL, NULL, NULL, NULL},
@@ -786,9 +803,24 @@ static PrefParam param[] = {
 #endif
 	/* {"emulate_emacs", "FALSE", &prefs_common.emulate_emacs, P_BOOL,
 	 NULL, NULL, NULL}, */
-	{"always_show_message_when_selected", "0",
+	{"open_selected_message_on_folder_open", "FALSE",
+	 &prefs_common.open_selected_on_folder_open,
+	 P_BOOL, NULL, NULL, NULL},
+	{"open_selected_message_on_search_results", "FALSE",
+	 &prefs_common.open_selected_on_search_results,
+	 P_BOOL, NULL, NULL, NULL},
+	{"open_selected_message_on_prevnext", "FALSE",
+	 &prefs_common.open_selected_on_prevnext,
+	 P_BOOL, NULL, NULL, NULL},
+	{"open_selected_message_on_deletemove", "FALSE",
+	 &prefs_common.open_selected_on_deletemove,
+	 P_BOOL, NULL, NULL, NULL},
+	{"open_selected_message_on_directional", "FALSE",
+	 &prefs_common.open_selected_on_directional,
+	 P_BOOL, NULL, NULL, NULL},
+	{"always_show_message_when_selected", "FALSE",
 	 &prefs_common.always_show_msg,
-	 P_ENUM, NULL, NULL, NULL},
+	 P_BOOL, NULL, NULL, NULL},
 	{"select_on_entry", "3", &prefs_common.select_on_entry,
 	 P_ENUM, NULL, NULL, NULL},
 	{"show_tooltips", "TRUE", &prefs_common.show_tooltips,
@@ -826,6 +858,20 @@ static PrefParam param[] = {
 	{"pixmap_theme_path", DEFAULT_PIXMAP_THEME, 
 	 &SPECIFIC_PREFS.pixmap_theme_path, P_STRING,
 	 NULL, NULL, NULL},
+#ifdef HAVE_SVG
+	{"enable_alpha_svg", "TRUE",
+	 &SPECIFIC_PREFS.enable_alpha_svg, P_BOOL,
+	 NULL, NULL, NULL},
+	{"enable_pixmap_scaling", "TRUE",
+	 &SPECIFIC_PREFS.enable_pixmap_scaling, P_BOOL,
+	 NULL, NULL, NULL},
+	{"pixmap_scaling_auto", "TRUE",
+	 &SPECIFIC_PREFS.pixmap_scaling_auto, P_BOOL,
+	 NULL, NULL, NULL},
+	{"pixmap_scaling_ppi", "96",
+	 &SPECIFIC_PREFS.pixmap_scaling_ppi, P_INT,
+	 NULL, NULL, NULL},
+#endif
 
 	{"ask_mark_all_read", "TRUE", &prefs_common.ask_mark_all_read, P_BOOL,
 	 NULL, NULL, NULL},
