@@ -1293,7 +1293,8 @@ static void prefs_filtering_action_select_dest(void)
 	FolderItem *dest;
 	gchar * path;
 
-	dest = foldersel_folder_sel(NULL, FOLDER_SEL_COPY, NULL, FALSE);
+	dest = foldersel_folder_sel(NULL, FOLDER_SEL_COPY, NULL, FALSE,
+			_("Select destination folder"));
 	if (!dest) return;
 
 	path = folder_item_get_identifier(dest);
