@@ -816,6 +816,7 @@ static void prefs_folder_item_compose_create_widget_func(PrefsPage * page_,
 	FolderItem *item = (FolderItem *) data;
 	guint rowcount;
 	gchar *text = NULL;
+	gchar *tr = NULL;
 
 	GtkWidget *table;
 	GtkWidget *label;
@@ -919,13 +920,16 @@ static void prefs_folder_item_compose_create_widget_func(PrefsPage * page_,
 		rowcount++;
 
 		/* Default To */
-		text = g_strconcat(_("Default "), prefs_common_translated_header_name("To:"), NULL);
+		tr = g_strdup(C_("folder properties: %s stands for a header name",
+				 	  "Default %s"));
+		text = g_strdup_printf(tr, prefs_common_translated_header_name("To:"));
 		checkbtn_default_to = gtk_check_button_new_with_label(text);
 		gtk_table_attach(GTK_TABLE(table), checkbtn_default_to, 0, 1, 
 				 rowcount, rowcount + 1, GTK_SHRINK | GTK_FILL, GTK_SHRINK, 0, 0);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_default_to), 
 					     item->prefs->enable_default_to);
 		g_free(text);
+		g_free(tr);
 
 		entry_default_to = gtk_entry_new();
 		gtk_table_attach(GTK_TABLE(table), entry_default_to, 1, 2,
@@ -942,14 +946,16 @@ static void prefs_folder_item_compose_create_widget_func(PrefsPage * page_,
 		rowcount++;
 
 		/* Default address to reply to */
-		text = g_strconcat(_("Default "), prefs_common_translated_header_name("To:"),
-				 _(" for replies"), NULL);
+		tr = g_strdup(C_("folder properties: %s stands for a header name",
+				 	  "Default %s for replies"));
+		text = g_strdup_printf(tr, prefs_common_translated_header_name("To:"));
 		checkbtn_default_reply_to = gtk_check_button_new_with_label(text);
 		gtk_table_attach(GTK_TABLE(table), checkbtn_default_reply_to, 0, 1, 
 				 rowcount, rowcount + 1, GTK_SHRINK | GTK_FILL, GTK_SHRINK, 0, 0);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_default_reply_to), 
 					     item->prefs->enable_default_reply_to);
 		g_free(text);
+		g_free(tr);
 
 		entry_default_reply_to = gtk_entry_new();
 		gtk_table_attach(GTK_TABLE(table), entry_default_reply_to, 1, 2,
@@ -966,13 +972,16 @@ static void prefs_folder_item_compose_create_widget_func(PrefsPage * page_,
 		rowcount++;
 
 		/* Default Cc */
-		text = g_strconcat(_("Default "), prefs_common_translated_header_name("Cc:"), NULL);
+		tr = g_strdup(C_("folder properties: %s stands for a header name",
+				 	  "Default %s"));
+		text = g_strdup_printf(tr, prefs_common_translated_header_name("Cc:"));
 		checkbtn_default_cc = gtk_check_button_new_with_label(text);
 		gtk_table_attach(GTK_TABLE(table), checkbtn_default_cc, 0, 1, 
 				 rowcount, rowcount + 1, GTK_SHRINK | GTK_FILL, GTK_SHRINK, 0, 0);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_default_cc), 
 					     item->prefs->enable_default_cc);
 		g_free(text);
+		g_free(tr);
 
 		entry_default_cc = gtk_entry_new();
 		gtk_table_attach(GTK_TABLE(table), entry_default_cc, 1, 2,
@@ -989,13 +998,16 @@ static void prefs_folder_item_compose_create_widget_func(PrefsPage * page_,
 		rowcount++;
 
 		/* Default Bcc */
-		text = g_strconcat(_("Default "), prefs_common_translated_header_name("Bcc:"), NULL);
+		tr = g_strdup(C_("folder properties: %s stands for a header name",
+				 	  "Default %s"));
+		text = g_strdup_printf(tr, prefs_common_translated_header_name("Bcc:"));
 		checkbtn_default_bcc = gtk_check_button_new_with_label(text);
 		gtk_table_attach(GTK_TABLE(table), checkbtn_default_bcc, 0, 1, 
 				 rowcount, rowcount + 1, GTK_SHRINK | GTK_FILL, GTK_SHRINK, 0, 0);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_default_bcc), 
 					     item->prefs->enable_default_bcc);
 		g_free(text);
+		g_free(tr);
 
 		entry_default_bcc = gtk_entry_new();
 		gtk_table_attach(GTK_TABLE(table), entry_default_bcc, 1, 2,
@@ -1012,13 +1024,16 @@ static void prefs_folder_item_compose_create_widget_func(PrefsPage * page_,
 		rowcount++;
 
 		/* Default Reply-to */
-		text = g_strconcat(_("Default "), prefs_common_translated_header_name("Reply-To:"), NULL);
+		tr = g_strdup(C_("folder properties: %s stands for a header name",
+				 	  "Default %s"));
+		text = g_strdup_printf(tr, prefs_common_translated_header_name("Reply-To:"));
 		checkbtn_default_replyto = gtk_check_button_new_with_label(text);
 		gtk_table_attach(GTK_TABLE(table), checkbtn_default_replyto, 0, 1, 
 				 rowcount, rowcount + 1, GTK_SHRINK | GTK_FILL, GTK_SHRINK, 0, 0);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbtn_default_replyto), 
 					     item->prefs->enable_default_replyto);
 		g_free(text);
+		g_free(tr);
 
 		entry_default_replyto = gtk_entry_new();
 		gtk_table_attach(GTK_TABLE(table), entry_default_replyto, 1, 2,
@@ -1747,9 +1762,11 @@ static void folder_regexp_test_cb(GtkWidget *widget, gpointer data)
 
 #if !GTK_CHECK_VERSION(3, 0, 0)
 	if (!colors_initialised) {
-		gdk_color_parse("#ff7070", &red);
-		colors_initialised = gdk_colormap_alloc_color(
-			gdk_colormap_get_system(), &red, FALSE, TRUE);
+		if (!gdk_color_parse("#ff7070", &red)) {
+	        g_warning("color parse failed: red");
+			colors_initialised = gdk_colormap_alloc_color(
+				gdk_colormap_get_system(), &red, FALSE, TRUE);
+		}
 	}
 #endif
 
